/*
  Copyright (c) 2008-2010, Xavier 'Xr' Dalem
  This file is part of Java API Browser

  Version 1.1

  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License version 3
  as published by the Free Software Foundation.
 
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  GNU General Public License for more details.
 
  You should have received a copy of the GNU General Public License
  along with this program. If not, see <http://www.gnu.org/licenses/>.
*/

/**                         KEYBOARD SHORTCUTS                              **/

function switchAPI() {
	var select = $('select#source').get(0);
	select.selectedIndex = (select.selectedIndex+1)%select.length;
	//$('input#query').trigger("change"); // Doesn't work... yet ?
}

/**                              COOKIES                                    **/

function createCookie(name,value,days) {
	var date = new Date();
	date.setTime(date.getTime()+(days*24*60*60*1000));
	document.cookie = name+'='+escape(value)+'; expires='+date.toGMTString()+'; path=/';
}

function readCookie(name) {
	name += '=';
	var parts = document.cookie.split(/\ *;\ */);
	
	for(var i=0; i < parts.length; i++)
		if (0 == parts[i].indexOf(name))
			return unescape(parts[i].substring(name.length));
	
	return null;
}

/**                              OPTIONS                                    **/

function getJABOptions() {
	var cookie = readCookie('JAB_options');
	
	if (null == cookie)
		return getDefaultJABOptions();
	
	// Deserialize
	var apis = cookie.split('|');
	var options = Array();
	for (var i=0; i < apis.length; i++) {
		var data = apis[i].split('§');
		options[i] = { name: data[0], url: data[1] };
	}
	
	return options;
}

function writeJABOptions(options) {
	var cookie = '';
	
	for (var i=0; i < options.length; i++) {
		cookie += options[i].name + '§' + options[i].url;
		if (i < options.length-1)
			cookie += '|';
	}
	
	createCookie('JAB_options', cookie, 30);
}

function resetJABOptions() {
	writeJABOptions(getDefaultJABOptions());
}

function getDefaultJABOptions() {
	return [
		{ name: 'Java SE 6', url: 'http://java.sun.com/javase/6/docs/api/' },
		{ name: 'Java 2 SE 1.5', url: 'http://java.sun.com/j2se/1.5.0/docs/api/' },
		{ name: 'Java 2 SE 1.4.2', url: 'http://java.sun.com/j2se/1.4.2/docs/api/' }
	];
}

/**                     CUSTOMIZATION MANIPULATIONS                         **/

var inputCount = 0;

function clearOptions() {
	$('fieldset#customize .removable').remove();
}

function loadOptions(options) {
	clearOptions();
	for (var i=options.length-1; i >=0; i--) {
		$('fieldset#customize legend').after(
			'<input type="text" id="name'+inputCount+'" class="removable name" value="'+options[i].name+'"/>'
			+'<input type="text" id="url'+inputCount+'" class="removable url" value="'+options[i].url+'"/>'
			+'<input type="button" id="remove'+inputCount+'" class="removable" value="-" onclick="removeOption('+inputCount+')" />'
			+'<br id="break'+inputCount+'" class="removable" />'
			);
		inputCount++;
	}
}

function removeOption(i) {
	$('input#name'+i).remove();
	$('input#url'+i).remove();
	$('input#remove'+i).remove();
	$('br#break'+i).remove();
}

function addOption() {
	$('input#adder').before(
		'<input type="text" id="name'+inputCount+'" class="removable name" value="" />'
		+'<input type="text" id="url'+inputCount+'" class="removable url" value=""/>'
		+'<input type="button" id="remove'+inputCount+'" class="removable" value="-" onclick="removeOption('+inputCount+')" />'
		+'<br id="break'+inputCount+'" class="removable" />'
	);
	inputCount++;
}

function saveOptions() {
	var i = 0;
	
	// Get all names
	var names = Array();
	$('fieldset#customize input.name').each(function() {names[i++] = this.value});
	
	// Get all urls
	var urls = Array(); i = 0;
	$('fieldset#customize input.url').each(function() {urls[i++] = this.value});
	
	if (names.length != urls.length) {
		alert('Uh-oh, not the same number of names and addresses');
		return false;
	}
	
	// Add to options if both fields aren't empty
	var options = Array(); i = 0;
	for (var j = 0; j < names.length; j++) {
		var n = names[j].replace(/^\s*/, '').replace(/\s*$/, '');
		var u = urls[j].replace(/^\s*/, '').replace(/\s*$/, '');
		options[i++] = { name: n , url: u };
	}
	
	// Save
	writeJABOptions(options);
	
	// Reload with changes
	window.location.reload(true);
}
